numpy.lib.user_array.container
==============================

.. currentmodule:: numpy.lib.user_array

.. autoclass:: container

   

   .. HACK
      .. autosummary::
         :toctree:
      
         container.__init__
         container.astype
         container.byteswap
         container.copy
         container.tostring



   

